==> verifier-3.0-b55-sources.jar: com/sun/enterprise/tools/verifier/app/ApplicationVerifier.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.enterprise.tools.verifier.app;

import com.sun.enterprise.deployment.Application;
import com.sun.enterprise.deployment.Descriptor;
import com.sun.enterprise.tools.verifier.BaseVerifier;
import com.sun.enterprise.tools.verifier.CheckMgr;
import com.sun.enterprise.tools.verifier.VerifierFrameworkContext;

/**
 * @author Vikas Awasthi
 */
public class ApplicationVerifier extends BaseVerifier {

    private Application application = null;

    public ApplicationVerifier(VerifierFrameworkContext verifierFrameworkContext,
                               Application application) {
        this.verifierFrameworkContext = verifierFrameworkContext;
        this.application = application;
    }

    /**
     * Responsible for running application based verifier tests on the the web archive.
     * Called from runVerifier in {@link BaseVerifier} class.
     *
     * @throws Exception
     */
    public void verify() throws Exception {
        if (areTestsNotRequired(verifierFrameworkContext.isApp()) &&
                areTestsNotRequired(verifierFrameworkContext.isPersistenceUnits()))
            return;
        preVerification();
        if(verifierFrameworkContext.isPortabilityMode())
            application.setClassLoader(context.getClassLoader());
        CheckMgr checkMgrImpl = new AppCheckMgrImpl(verifierFrameworkContext);
        verify(application, checkMgrImpl);
    }

    public Descriptor getDescriptor() {
        return application;
    }

    protected ClassLoader createClassLoader() {
        return application.getClassLoader();
    }

    /**
     * @return String archive base
     */
    protected String getArchiveUri() {
        return verifierFrameworkContext.getJarFileName();
    }

    protected String[] getDDString() {
        String dd[] = {"META-INF/sun-application.xml", // NOI18N
                       "META-INF/application.xml"}; // NOI18N
        return dd;
    }

    protected String getClassPath() {
        return null;
    }
}

==> verifier-3.1-b28-sources.jar: com/sun/enterprise/tools/verifier/app/ApplicationVerifier.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.tools.verifier.app;

import com.sun.enterprise.deployment.Application;
import com.sun.enterprise.deployment.Descriptor;
import com.sun.enterprise.tools.verifier.BaseVerifier;
import com.sun.enterprise.tools.verifier.CheckMgr;
import com.sun.enterprise.tools.verifier.VerifierFrameworkContext;

/**
 * @author Vikas Awasthi
 */
public class ApplicationVerifier extends BaseVerifier {

    private Application application = null;

    public ApplicationVerifier(VerifierFrameworkContext verifierFrameworkContext,
                               Application application) {
        this.verifierFrameworkContext = verifierFrameworkContext;
        this.application = application;
    }

    /**
     * Responsible for running application based verifier tests on the the web archive.
     * Called from runVerifier in {@link BaseVerifier} class.
     *
     * @throws Exception
     */
    public void verify() throws Exception {
        if (areTestsNotRequired(verifierFrameworkContext.isApp()) &&
                areTestsNotRequired(verifierFrameworkContext.isPersistenceUnits()))
            return;
        preVerification();
        if(verifierFrameworkContext.isPortabilityMode())
            application.setClassLoader(context.getClassLoader());
        CheckMgr checkMgrImpl = new AppCheckMgrImpl(verifierFrameworkContext);
        verify(application, checkMgrImpl);
    }

    public Descriptor getDescriptor() {
        return application;
    }

    protected ClassLoader createClassLoader() {
        return application.getClassLoader();
    }

    /**
     * @return String archive base
     */
    protected String getArchiveUri() {
        return verifierFrameworkContext.getJarFileName();
    }

    protected String[] getDDString() {
        String dd[] = {"META-INF/sun-application.xml", // NOI18N
                       "META-INF/application.xml", 
                       "META-INF/glassfish-application.xml"}; // NOI18N
        return dd;
    }

    protected String getClassPath() {
        return null;
    }
}
